#!/bin/sh


# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# this script is public domain
# there is no warranty



export DOCSBASENAME="README.tausta"
export DOCTITLE="tausta.ksh.sh"
export DOCAUTHOR="Juhapekka Tolvanen"
export TWOLETTERLANG="en"
export TOCTITLE="Table of Contents"


### You may want to use this during debugging:
#MYXELATEXCMD="xelatex -src-specials -file-line-error -recorder"
### This should be normally enough:
MYXELATEXCMD="xelatex -src-specials"

### LaTeX http://en.wikipedia.org/wiki/LaTeX
### portrait http://en.wikipedia.org/wiki/Page_orientation
rm -fv ${DOCSBASENAME}.aux ${DOCSBASENAME}.bbl ${DOCSBASENAME}.blg \
  ${DOCSBASENAME}.brf ${DOCSBASENAME}.tmp ${DOCSBASENAME}.log \
  ${DOCSBASENAME}.toc ${DOCSBASENAME}.lot ${DOCSBASENAME}.out \
  ${DOCSBASENAME}.tex ${DOCSBASENAME}.pdf ${DOCSBASENAME}.ps \
  ${DOCSBASENAME}.fls

### http://en.wikipedia.org/wiki/ReStructuredText
### http://docutils.sourceforge.net/
### http://docutils.sourceforge.net/rst.html
rst2xetex \
    --stylesheet=RST_Palatino_MPlus \
    --language=${TWOLETTERLANG} --report=5 --toc-entry-backlinks \
    --section-numbering --strip-comments \
    --use-verbatim-when-possible \
    --hyperlink-color=false \
    --use-part-section \
    --compound-enumerators --section-prefix-for-enumerators --section-subtitles \
    ${DOCSBASENAME}.txt \
    ${DOCSBASENAME}.tex

### http://en.wikipedia.org/wiki/XeTeX
${MYXELATEXCMD} ${DOCSBASENAME}.tex
while grep 'Rerun to get' ${DOCSBASENAME}.log > /dev/null
do
    ${MYXELATEXCMD} ${DOCSBASENAME}.tex
done
${MYXELATEXCMD} ${DOCSBASENAME}.tex


### You may need to comment these away during debugging:
rm -fv ${DOCSBASENAME}.aux ${DOCSBASENAME}.bbl ${DOCSBASENAME}.blg \
    ${DOCSBASENAME}.brf ${DOCSBASENAME}.tmp ${DOCSBASENAME}.log \
    ${DOCSBASENAME}.toc ${DOCSBASENAME}.lot ${DOCSBASENAME}.out \
    ${DOCSBASENAME}.fls

### http://en.wikipedia.org/wiki/Portable_Document_Format
### http://en.wikipedia.org/wiki/Poppler_%28software%29
### http://poppler.freedesktop.org/
### http://en.wikipedia.org/wiki/PostScript
pdftops -level2 -paper A4 -expand ${DOCSBASENAME}.pdf



### LaTeX
### landscape
rm -fv ${DOCSBASENAME}.landscape.aux ${DOCSBASENAME}.landscape.bbl ${DOCSBASENAME}.landscape.blg \
    ${DOCSBASENAME}.landscape.brf ${DOCSBASENAME}.landscape.tmp ${DOCSBASENAME}.landscape.log \
    ${DOCSBASENAME}.landscape.toc ${DOCSBASENAME}.landscape.lot ${DOCSBASENAME}.landscape.out \
    ${DOCSBASENAME}.landscape.tex ${DOCSBASENAME}.landscape.pdf ${DOCSBASENAME}.landscape.ps \
    ${DOCSBASENAME}.landscape.fls

rst2xetex \
    --config=./docutils.landscape.conf --stylesheet=RST_landscape \
    --language=${TWOLETTERLANG} --report=5 --toc-entry-backlinks \
    --section-numbering --strip-comments \
    --use-verbatim-when-possible \
    --compound-enumerators --section-prefix-for-enumerators --section-subtitles \
    ${DOCSBASENAME}.txt \
    ${DOCSBASENAME}.landscape.tex

${MYXELATEXCMD} ${DOCSBASENAME}.landscape.tex
while grep 'Rerun to get' ${DOCSBASENAME}.landscape.log > /dev/null
do
   ${MYXELATEXCMD} ${DOCSBASENAME}.landscape.tex
done
${MYXELATEXCMD} ${DOCSBASENAME}.landscape.tex

### You may need to comment these away during debugging:
rm -fv ${DOCSBASENAME}.landscape.aux ${DOCSBASENAME}.landscape.bbl ${DOCSBASENAME}.landscape.blg \
    ${DOCSBASENAME}.landscape.brf ${DOCSBASENAME}.landscape.tmp ${DOCSBASENAME}.landscape.log \
    ${DOCSBASENAME}.landscape.toc ${DOCSBASENAME}.landscape.lot ${DOCSBASENAME}.landscape.out \
    ${DOCSBASENAME}.landscape.fls

pdftops -level2 -paper A4 -expand ${DOCSBASENAME}.landscape.pdf


### (X)HTML
### http://en.wikipedia.org/wiki/HTML
### http://en.wikipedia.org/wiki/XHTML
rm -fv ${DOCSBASENAME}.html
rst2html --language=${TWOLETTERLANG} --report=5 --toc-entry-backlinks \
  --footnote-backlinks --section-numbering --strip-comments \
  ${DOCSBASENAME}.txt ${DOCSBASENAME}.html

### FIXME : If you want also those more exotic formats, (re)move that
### exit-command and/or add comments to those commands you don’t want
### to run.
echo "I just made two PDF-files and two PostScript-files, in portrait and landscape orientation and one XHTML-file for you. If you want also more exotic formats (for example EPUB), edit this script close to FIXME." | fmt
exit 0


### man http://en.wikipedia.org/wiki/Man_page
rm -fv ${DOCSBASENAME}.man
rst2man --title="$DOCSBASENAME" -g -d -t --report=5 --strip-comments ${DOCSBASENAME}.txt ${DOCSBASENAME}.man


### DjVU http://en.wikipedia.org/wiki/DjVu
### http://code.google.com/p/pdf2djvu/
rm -fv ${DOCSBASENAME}.djvu
pdf2djvu -d 400 --verbatim-metadata -o ${DOCSBASENAME}.djvu ${DOCSBASENAME}.pdf

rm -fv ${DOCSBASENAME}.landscape.djvu
pdf2djvu -d 400 --verbatim-metadata -o ${DOCSBASENAME}.landscape.djvu ${DOCSBASENAME}.landscape.pdf

### texinfo http://en.wikipedia.org/wiki/Texinfo
rm -fv ${DOCSBASENAME}.texi
### http://johnmacfarlane.net/pandoc/
pandoc -f rst -t texinfo -s -o ${DOCSBASENAME}.texi ${DOCSBASENAME}.txt
### info http://en.wikipedia.org/wiki/Info_%28Unix%29
rm -fv ${DOCSBASENAME}.info
makeinfo -v --number-sections --no-split --enable-encoding ${DOCSBASENAME}.texi

### RTF http://en.wikipedia.org/wiki/Rich_Text_Format
### VIAT: Sisällysluettelo puuttuu täysin.
rm -fv ${DOCSBASENAME}.rtf
pandoc --toc -f rst -t rtf -s -o ${DOCSBASENAME}.rtf ${DOCSBASENAME}.txt

### Plain text http://en.wikipedia.org/wiki/Plain_text
rm -fv ${DOCSBASENAME}.plain.txt
pandoc --toc -f rst -t plain -s -o ${DOCSBASENAME}.plain.txt  ${DOCSBASENAME}.txt

### To be used in very narrow windows, for example in Nintendo DS Lite
### and its homebrew software called Moonshell.
### http://en.wikipedia.org/wiki/MoonShell
rm -fv ${DOCSBASENAME}.plain40.txt
pandoc --columns=39 --toc -f rst -t plain -s -o ${DOCSBASENAME}.plain40.txt ${DOCSBASENAME}.txt


### ODT http://en.wikipedia.org/wiki/OpenDocument

### VIAT: Sisällysluettelo puuttuu täysin. Kieli on muka
### amerikanenglanti
#rm -fv ${DOCSBASENAME}.odt
### http://johnmacfarlane.net/pandoc/
#pandoc --toc -f rst -t odt -s -o ${DOCSBASENAME}.odt ${DOCSBASENAME}.txt


### VIAT: Sisällysluettelo mukana, mutta sen sivunumerot pitäisi
### päivittää käsin OpenOffice.org:issa
### Dokumentin kieli on muka amerikanenglanti.
rm -fv ${DOCSBASENAME}.odt
rst2odt --generator --date --time --toc-entry-backlinks \
  --footnote-backlinks --section-numbering --strip-comments \
  --language=${TWOLETTERLANG} \
  --title="${DOCTITLE}" \
  ${DOCSBASENAME}.txt ${DOCSBASENAME}.odt


### DOCX http://en.wikipedia.org/wiki/Office_Open_XML
rm -fv ${DOCSBASENAME}.docx
pandoc --toc -f rst -t docx -s -o ${DOCSBASENAME}.docx ${DOCSBASENAME}.txt


### DocBook XML
### http://en.wikipedia.org/wiki/DocBook
### http://en.wikipedia.org/wiki/XML
rm -fv ${DOCSBASENAME}.xml
pandoc -f rst -t docbook -s ${DOCSBASENAME}.txt \
    > ${DOCSBASENAME}.xml

### pandoc:in versiossa 1.6 oli tällainen bugi:
### http://bugs.debian.org/611328
### Se korjattiin versiossa 1.8 (2011–01–30):
### http://johnmacfarlane.net/pandoc/releases.html
### ”Skip blank lines at beginning of file. Resolves Debian #611328.”
### Mutta jos pandoc on tuolla lailla buginen, voidaan se bugi kiertää
### jättämällä dokumentin alusta tyhjät rivit veks.
#    | sed 's/\#*//g' \
#    | sed 's/<title><\/title>/<title>Läsnäolon voima -kirjan harjoitukset<\/title>/' \
#    > ${DOCSBASENAME}.xml



### eBook-formats:

### EPUB  http://en.wikipedia.org/wiki/EPUB

### http://fedorahosted.org/publican/
### VIAT: Teksti usein liian kiinni lihavoidun tekstin perässä.
#rm -fv ${DOCSBASENAME}.epub
#cp -fv ${DOCSBASENAME}.xml publican/fi/${DOCSBASENAME}.xml
#cd publican/fi/
#tidy -m -xml -utf8 ${DOCSBASENAME}.xml
#cd ..
#publican clean
#publican clean_ids
###rm -fv ../publican_errors.txt
###publican build --langs=fi --formats=test --nocolours 2> ../publican_errors.txt
###publican build --langs=fi --formats=test
#publican build --langs=fi --formats=epub
#cp -fv tmp/fi/harjoitukset-0-harjoitukset-fi.epub ../${DOCSBASENAME}.epub
#publican clean
#publican clean_ids
#cd ..


### http://docbook.sourceforge.net/release/xsl/current/epub/README
#rm -fv ${DOCSBASENAME}.epub
#dbtoepub -o ${DOCSBASENAME}.epub ${DOCSBASENAME}.xml
rm -fv ${DOCSBASENAME}.epub
pandoc --toc -f rst -t epub -s -o ${DOCSBASENAME}.epub ${DOCSBASENAME}.txt

### http://en.wikipedia.org/wiki/Calibre_%28software%29

### FB2 http://en.wikipedia.org/wiki/FictionBook
rm -fv ${DOCSBASENAME}.fb2
echo ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.fb2 -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}
ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.fb2 -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}


### MOBI (.mobi or .prc) http://en.wikipedia.org/wiki/Mobipocket
rm -fv ${DOCSBASENAME}.mobi
echo ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.mobi -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG} --toc-title  "${TOCTITLE}"
ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.mobi -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG} --toc-title  "${TOCTITLE}"

### LIT http://en.wikipedia.org/wiki/Microsoft_Reader
rm -fv ${DOCSBASENAME}.lit
echo ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.lit -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}
ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.lit -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}

### PDB (and PML ?) http://en.wikipedia.org/wiki/PDB_%28Palm_OS%29
rm -fv ${DOCSBASENAME}.pdb
echo ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.pdb -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}
ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.pdb -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}

### LRF http://en.wikipedia.org/wiki/BBeB
rm -fv ${DOCSBASENAME}.lrf
echo ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.lrf -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}
ebook-convert ${DOCSBASENAME}.epub ${DOCSBASENAME}.lrf -vv --authors "${DOCAUTHOR}" --pretty-print --base-font-size 12 --font-size-mapping 10,12,14,16,18,20,22,24 --insert-blank-line --language ${TWOLETTERLANG}


### Other formats:

# Next to be added:
# (none)

# xmlto can convert DocBook-XML to CHM, but it refuses to convert my
# XML created with pandoc
# CHM http://en.wikipedia.org/wiki/Microsoft_Compiled_HTML_Help

### Definitely too old:
### Calibre can output these, though.

# OEB (.opf) http://en.wikipedia.org/wiki/Open_eBook
# Superseded by EPUB

# TCR http://en.wikipedia.org/wiki/TCR
# Text Compression for Reader (.tcr), a compressed text file format
# used by Psion e-book reader software

### Unknown formats (in Wikipedia):
### Calibre can output these, though.

# RB (RocketBook or RocketEdition)
# http://filext.com/file-extension/RB

# SNB (Shanda Bambook eBook file)
# http://www.file-extensions.org/snb-file-extension


